ParsedDidKey class

A decoded did:key identifier: the key type plus the compressed public key bytes.

Constructors

ParsedDidKey({required KeyType type, required Uint8List publicKey})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
publicKey Uint8List
The compressed (33 byte) public key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type KeyType
The elliptic curve of the key.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited